fhs_xmltv_tools
===============


I wanted to know more about the xmltv xml file i downloaded for my iptv and i wanted to know how it all worked.
So i am startig to create my own tools

See pypi: https://pypi.org/project/fhs-xmltv-tools/

Clean up xmltv files, with only the channels you want and even join multiple together,
also easy if you need to change timezone from one of the files.


Usage
-----

Installation
------------

.. code-block:: bash

  git clone https://github.com/foxhunt72/fhs-xmltv-tools
  cd fhs-xmltv-tools
  pip3 install .

  # And in the future also

  pipx install fhs_xmltv_tools
  or
  pip3 install fhs_xmltv_tools

Scripts yaml exaple
~~~~~~~~~~~~~~~~~~~

Todo add yaml example


Requirements
^^^^^^^^^^^^
- typer[all]
- py-xmltv
- pyyaml

Compatibility
-------------


Licence
-------
MIT Licencse

Authors
-------
Richard de Vos

`fhs_xmltv_tools` was written by `Richard de Vos <rdevos72@gmail.com>`_.
